@@ -72,19 +72,19 @@ def ascii_art():
     )
 
 
-class Logger(object):
-    def flush(self):
-        pass
+# class Logger(object):
+#     def flush(self):
+#         pass
 
-    def __init__(self):
-        self.terminal = sys.stdout
-        filename = datetime.now().strftime("migrator_%H_%M_%d_%m_%Y.log")
-        # self.log = open(f"./{filename}", "a")
-        self.log = open(f"./{filename}", "a", encoding="utf-8")
+#     def __init__(self):
+#         self.terminal = sys.stdout
+#         filename = datetime.now().strftime("migrator_%H_%M_%d_%m_%Y.log")
+#         # self.log = open(f"./{filename}", "a")
+#         self.log = open(f"./{filename}", "a", encoding="utf-8")
 
-    def write(self, message):
-        self.terminal.write(message)
-        self.log.write(message)
+#     def write(self, message):
+#         self.terminal.write(message)
+#         self.log.write(message)
 
 
 # override the click invoke method
@@ -106,22 +106,34 @@ def CommandWithConfigFile(config_file_param_name):
 
 
 def validate_api_keys(ctx, param, api_key):
-    last_equal = api_key[-1] == "="
-    first_validation_bit = api_key.split("-")
-    last_validation_bit = first_validation_bit[4].split(":")
-    clean_list = [i for i in first_validation_bit[0:4]]
-    clean_list.append(last_validation_bit[0])
-    validate_list = [len(i) for i in clean_list]
-    validate_list.append(last_equal)
+    try:
+        last_equal = api_key[-1] == "="
+        first_validation_bit = api_key.split("-")
+        last_validation_bit = first_validation_bit[4].split(":")
+        clean_list = [i for i in first_validation_bit[0:4]]
+        clean_list.append(last_validation_bit[0])
+        validate_list = [len(i) for i in clean_list]
+        validate_list.append(last_equal)
 
-    if validate_list == [8, 4, 4, 4, 12, True]:
-        return api_key
-    else:
+        if validate_list == [8, 4, 4, 4, 12, True]:
+            return api_key
+        else:
+            raise click.BadParameter(
+                "Invalid API key format, please double-check the input."
+            )
+    except:
         raise click.BadParameter(
             "Invalid API key format, please double-check the input."
         )
 
 
+ascii_art()
+console.print(
+    "Welcome to the Trend Micro Policy Migration Tool",
+    style="bold red",
+)
+
+
 @click.command(cls=CommandWithConfigFile("config_file"))
 @click.option("--config-file", type=click.Path(), is_eager=True)
 @click.option(
@@ -192,8 +204,6 @@ def main(
     delete_policies,
 ):
     """Moves your on-prem DS deployment to the cloud!"""
-    # sys.stdout = Logger()
-    # sys.stderr = sys.stdout
     OLD_API_KEY = original_api_key
     OLD_HOST = original_url
     NEW_API_KEY = cloud_one_api_key
@@ -336,10 +346,5 @@ def main(
 
 if __name__ == "__main__":
     filename = datetime.now().strftime("migrator_%H_%M_%d_%m_%Y.log")
-    ascii_art()
-    console.print(
-        "Welcome to the Trend Micro Policy Migration Tool",
-        style="bold red",
-    )
     main()  # pylint: disable=no-value-for-parameter
     console.save_text(filename)
