@@ -3,6 +3,7 @@ import os
 import requests
 import urllib3
 import json
+from dsmigrator.logging import console
 from dsmigrator.api_config import ComputerGroupsApiInstance
 from dsmigrator.migrator_utils import validate_create_dict, value_exists, rename_json
 from deepsecurity.rest import ApiException
@@ -43,7 +44,7 @@ def ListGroup(url_link_final, tenant1key):
 def GetGroup(etIDs, url_link_final, tenant1key):
     allet = []
     nameet = []
-    print("Getting Target Task...", flush=True)
+    console.log("Getting Target Task...")
     if etIDs:
         for part in etIDs:
             payload = {}
@@ -64,7 +65,7 @@ def GetGroup(etIDs, url_link_final, tenant1key):
 
 
 def CreateGroup(allet, nameet, url_link_final_2, tenant2key):
-    print("Creating group to target Account...", flush=True)
+    console.log("Creating group to target Account...")
     if nameet:
         modet = []
         for task in allet:
