@@ -5,6 +5,7 @@ from time import sleep
 import requests
 import urllib3
 import json
+from dsmigrator.logging import console
 from dsmigrator.api_config import (
     DirectoryListsApiInstance,
     FileListsApiInstance,
@@ -87,7 +88,7 @@ def schedule_listmaker(OLD_HOST, OLD_API_KEY, NEW_HOST, NEW_API_KEY):
 
 def DirListTenant1(directorylist, url_link_final, tenant1key):
     alldirectory = []
-    print("Getting lists from Tenant 1, if any.", flush=True)
+    console.log("Getting lists from Tenant 1, if any.")
     for dirlist in directorylist:
         payload = {}
         url = url_link_final + "api/directorylists/" + str(dirlist)
@@ -101,8 +102,8 @@ def DirListTenant1(directorylist, url_link_final, tenant1key):
         )
         describe = str(response.text)
         alldirectory.append(describe)
-    print("Tenant1 directory list", flush=True)
-    print(directorylist, flush=True)
+    console.log("Tenant1 directory list")
+    console.log(directorylist)
     return alldirectory
 
 
@@ -121,8 +122,8 @@ def FileExtensionListTenant1(fileextentionlist, url_link_final, tenant1key):
         )
         describe = str(response.text)
         allfileextention.append(describe)
-    print("Tenant1 file extention list", flush=True)
-    print(fileextentionlist, flush=True)
+    console.log("Tenant1 file extention list")
+    console.log(fileextentionlist)
     return allfileextention
 
 
@@ -141,8 +142,8 @@ def FileListTenant1(filelist, url_link_final, tenant1key):
         )
         describe = str(response.text)
         allfilelist.append(describe)
-    print("Tenant1 file list", flush=True)
-    print(filelist, flush=True)
+    console.log("Tenant1 file list")
+    console.log(filelist)
     return allfilelist
 
 
@@ -173,36 +174,36 @@ def RenameLists(alldirectory, allfilelist, allfileextention):
 
 
 def DirListTenant2(alldirectory, NEW_API_KEY):
-    print("Creating directory list in tenant 2, if any", flush=True)
+    console.log("Creating directory list in tenant 2, if any")
     alldirectorynew = []
     if alldirectory:
         alldirectorynew = validate_create(
             alldirectory, DirectoryListsApiInstance(NEW_API_KEY), "directory"
         )
-        print("new directory list", flush=True)
-    print(alldirectorynew, flush=True)
+        console.log("new directory list")
+    console.log(alldirectorynew)
     return alldirectorynew
 
 
 def FileListTenant2(allfile, NEW_API_KEY):
-    print("Creating file list in tenant 2, if any", flush=True)
+    console.log("Creating file list in tenant 2, if any")
     allfilenew = []
     if allfile:
         allfilenew = validate_create(allfile, FileListsApiInstance(NEW_API_KEY), "file")
-    print("new file list", flush=True)
-    print(allfilenew, flush=True)
+    console.log("new file list")
+    console.log(allfilenew)
     return allfilenew
 
 
 def FileExtensionListTenant2(allfileext, NEW_API_KEY):
-    print("Creating file extension list in tenant 2, if any", flush=True)
+    console.log("Creating file extension list in tenant 2, if any")
     allfileextnew = []
     if allfileext:
         allfileextnew = validate_create(
             allfileext, FileExtensionListsApiInstance(NEW_API_KEY), "file extension"
         )
-    print("new file extension list", flush=True)
-    print(allfileextnew, flush=True)
+    console.log("new file extension list")
+    console.log(allfileextnew)
     return allfileextnew
 
 
@@ -210,7 +211,7 @@ def PortListGet(url_link_final, tenant1key):
     t1portlistall = []
     t1portlistname = []
     t1portlistid = []
-    print("Getting All Port List...", flush=True)
+    console.log("Getting All Port List...")
     payload = {}
     url = url_link_final + "api/portlists"
     headers = {
@@ -225,18 +226,16 @@ def PortListGet(url_link_final, tenant1key):
         for count, here in enumerate(ports_json):
             t1portlistall.append(str(json.dumps(here)))
             t1portlistname.append(str(here["name"]))
-            print(
-                "#" + str(count) + " Port List name: " + str(here["name"]), flush=True
-            )
+            console.log("#" + str(count) + " Port List name: " + str(here["name"]))
             t1portlistid.append(str(here["ID"]))
-            print("#" + str(count) + " Port List ID: " + str(here["ID"]), flush=True)
-        print("Done!", flush=True)
+            console.log("#" + str(count) + " Port List ID: " + str(here["ID"]))
+        console.log("Done!")
     return t1portlistall, t1portlistname, t1portlistid
 
 
 def PortListCreate(t1portlistall, t1portlistname, url_link_final_2, tenant2key):
     t2portlistid = []
-    print("Transfering All Port List...", flush=True)
+    console.log("Transfering All Port List...")
     for count, dirlist in enumerate(t1portlistname):
         payload = (
             '{"searchCriteria": [{"fieldName": "name","stringValue": "'
@@ -276,7 +275,7 @@ def PortListCreate(t1portlistall, t1portlistname, url_link_final_2, tenant2key):
                             "POST", url, headers=headers, data=payload, verify=cert
                         )
                         t2portlistid.append(str(indexid))
-                        print("#" + str(count) + " Port List ID:" + indexid, flush=True)
+                        console.log("#" + str(count) + " Port List ID:" + indexid)
         else:
             payload = t1portlistall[count]
             url = url_link_final_2 + "api/portlists"
@@ -300,11 +299,11 @@ def PortListCreate(t1portlistall, t1portlistname, url_link_final_2, tenant2key):
                     ):  # i.e. both quotes were found
                         indexid = indexpart[startIndex + 1 : endIndex]
                         t2portlistid.append(str(indexid))
-                        print("#" + str(count) + " Port List ID:" + indexid, flush=True)
+                        console.log("#" + str(count) + " Port List ID:" + indexid)
             else:
-                print(describe, flush=True)
-                print(payload, flush=True)
-    print("Done!", flush=True)
+                console.log(describe)
+                console.log(payload)
+    console.log("Done!")
     return t2portlistid
 
 
@@ -312,7 +311,7 @@ def MacListGet(url_link_final, tenant1key):
     t1maclistall = []
     t1maclistname = []
     t1maclistid = []
-    print("Getting All Mac List...", flush=True)
+    console.log("Getting All Mac List...")
     payload = {}
     url = url_link_final + "api/maclists"
     headers = {
@@ -327,17 +326,17 @@ def MacListGet(url_link_final, tenant1key):
         for count, here in enumerate(mac_json):
             t1maclistall.append(str(json.dumps(here)))
             t1maclistname.append(str(here["name"]))
-            print("#" + str(count) + " Mac List name: " + str(here["name"]), flush=True)
+            console.log("#" + str(count) + " Mac List name: " + str(here["name"]))
             t1maclistid.append(str(here["ID"]))
-            print("#" + str(count) + " Mac List ID: " + str(here["ID"]), flush=True)
+            console.log("#" + str(count) + " Mac List ID: " + str(here["ID"]))
 
-        print("Done!", flush=True)
+        console.log("Done!")
     return t1maclistname, t1maclistid
 
 
 def MacListCreate(t1maclistall, t1maclistname, url_link_final_2, tenant2key):
     t2maclistid = []
-    print("Transfering All Mac List...", flush=True)
+    console.log("Transfering All Mac List...")
     for count, dirlist in enumerate(t1maclistname):
         payload = (
             '{"searchCriteria": [{"fieldName": "name","stringValue": "'
@@ -377,7 +376,7 @@ def MacListCreate(t1maclistall, t1maclistname, url_link_final_2, tenant2key):
                             "POST", url, headers=headers, data=payload, verify=cert
                         )
                         t2maclistid.append(str(indexid))
-                        print("#" + str(count) + " MAC List ID: " + indexid, flush=True)
+                        console.log("#" + str(count) + " MAC List ID: " + indexid)
         else:
             payload = t1maclistall[count]
             url = url_link_final_2 + "api/maclists"
@@ -401,11 +400,11 @@ def MacListCreate(t1maclistall, t1maclistname, url_link_final_2, tenant2key):
                     ):  # i.e. both quotes were found
                         indexid = indexpart[startIndex + 1 : endIndex]
                         t2maclistid.append(str(indexid))
-                        print("#" + str(count) + " MAC List ID: " + indexid, flush=True)
+                        console.log("#" + str(count) + " MAC List ID: " + indexid)
             else:
-                print(describe, flush=True)
-                print(payload, flush=True)
-    print("Done!", flush=True)
+                console.log(describe)
+                console.log(payload)
+    console.log("Done!")
     return t2maclistid
 
 
@@ -413,7 +412,7 @@ def IpListGet(url_link_final, tenant1key):
     t1iplistall = []
     t1iplistname = []
     t1iplistid = []
-    print("Getting All IP List...", flush=True)
+    console.log("Getting All IP List...")
     payload = {}
     url = url_link_final + "api/iplists"
     headers = {
@@ -428,16 +427,16 @@ def IpListGet(url_link_final, tenant1key):
         for count, here in enumerate(ip_json):
             t1iplistall.append(str(json.dumps(here)))
             t1iplistname.append(str(here["name"]))
-            print("#" + str(count) + " IP List name: " + str(here["name"]), flush=True)
+            console.log("#" + str(count) + " IP List name: " + str(here["name"]))
             t1iplistid.append(str(here["ID"]))
-            print("#" + str(count) + " IP List ID: " + str(here["ID"]), flush=True)
-        print("Done!", flush=True)
+            console.log("#" + str(count) + " IP List ID: " + str(here["ID"]))
+        console.log("Done!")
     return t1iplistname, t1iplistid
 
 
 def IpListCreate(t1iplistall, t1iplistname, url_link_final_2, tenant2key):
     t2iplistid = []
-    print("Transfering All IP List...", flush=True)
+    console.log("Transfering All IP List...")
     for count, dirlist in enumerate(t1iplistname):
         payload = (
             '{"searchCriteria": [{"fieldName": "name","stringValue": "'
@@ -477,7 +476,7 @@ def IpListCreate(t1iplistall, t1iplistname, url_link_final_2, tenant2key):
                             "POST", url, headers=headers, data=payload, verify=cert
                         )
                         t2iplistid.append(str(indexid))
-                        print("#" + str(count) + " IP List ID: " + indexid, flush=True)
+                        console.log("#" + str(count) + " IP List ID: " + indexid)
         else:
             payload = t1iplistall[count]
             url = url_link_final_2 + "api/iplists"
@@ -501,11 +500,11 @@ def IpListCreate(t1iplistall, t1iplistname, url_link_final_2, tenant2key):
                     ):  # i.e. both quotes were found
                         indexid = indexpart[startIndex + 1 : endIndex]
                         t2iplistid.append(str(indexid))
-                        print("#" + str(count) + " IP List ID: " + indexid, flush=True)
+                        console.log("#" + str(count) + " IP List ID: " + indexid)
             else:
-                print(describe, flush=True)
-                print(payload, flush=True)
-    print("Done!", flush=True)
+                console.log(describe)
+                console.log(payload)
+    console.log("Done!")
     return t2iplistid
 
 
@@ -513,7 +512,7 @@ def StatefulGet(url_link_final, tenant1key):
     t1statefulall = []
     t1statefulname = []
     t1statefulid = []
-    print("Getting All Stateful Configuration...", flush=True)
+    console.log("Getting All Stateful Configuration...")
     payload = {}
     url = url_link_final + "api/statefulconfigurations"
     headers = {
@@ -528,21 +527,18 @@ def StatefulGet(url_link_final, tenant1key):
         for count, here in enumerate(stateful_json):
             t1statefulall.append(str(json.dumps(here)))
             t1statefulname.append(str(here["name"]))
-            print(
+            console.log(
                 "#" + str(count) + " Stateful Config name: " + str(here["name"]),
-                flush=True,
             )
             t1statefulid.append(str(here["ID"]))
-            print(
-                "#" + str(count) + " Stateful Config ID: " + str(here["ID"]), flush=True
-            )
-        print("Done", flush=True)
+            console.log("#" + str(count) + " Stateful Config ID: " + str(here["ID"]))
+        console.log("Done")
     return t1statefulall, t1statefulname, t1statefulid
 
 
 def StatefulCreate(t1statefulall, t1statefulname, url_link_final_2, tenant2key):
     t2statefulid = []
-    print("Transfering All Stateful Configuration...", flush=True)
+    console.log("Transfering All Stateful Configuration...")
     if t1statefulname:
         for count, dirlist in enumerate(t1statefulname):
             payload = (
@@ -582,19 +578,17 @@ def StatefulCreate(t1statefulall, t1statefulname, url_link_final_2, tenant2key):
                         describe = str(response.text)
                         taskjson1 = json.loads(describe)
                         t2statefulid.append(str(taskjson1["ID"]))
-                        print(
+                        console.log(
                             "#"
                             + str(count)
                             + " Stateful Config name: "
                             + taskjson1["name"],
-                            flush=True,
                         )
-                        print(
+                        console.log(
                             "#"
                             + str(count)
                             + " Stateful Config ID: "
                             + str(taskjson1["ID"]),
-                            flush=True,
                         )
                 else:
                     payload = t1statefulall[count]
@@ -610,21 +604,19 @@ def StatefulCreate(t1statefulall, t1statefulname, url_link_final_2, tenant2key):
                     describe = str(response.text)
                     taskjson = json.loads(describe)
                     t2statefulid.append(str(taskjson["ID"]))
-                    print(
+                    console.log(
                         "#" + str(count) + " Stateful Config name: " + taskjson["name"],
-                        flush=True,
                     )
-                    print(
+                    console.log(
                         "#"
                         + str(count)
                         + " Stateful Config ID: "
                         + str(taskjson["ID"]),
-                        flush=True,
                     )
             else:
-                print(describe, flush=True)
-                print(payload, flush=True)
-    print("Done!", flush=True)
+                console.log(describe)
+                console.log(payload)
+    console.log("Done!")
     return t2statefulid
 
 
@@ -632,7 +624,7 @@ def ContextGet(url_link_final, tenant1key):
     t1contextall = []
     t1contextname = []
     t1contextid = []
-    print("Getting All Context Configuration...", flush=True)
+    console.log("Getting All Context Configuration...")
     payload = {}
     url = url_link_final + "api/contexts"
     headers = {
@@ -647,21 +639,18 @@ def ContextGet(url_link_final, tenant1key):
         for count, here in enumerate(contexts_json):
             t1contextall.append(str(json.dumps(here)))
             t1contextname.append(str(here["name"]))
-            print(
+            console.log(
                 "#" + str(count) + " Context Config name: " + str(here["name"]),
-                flush=True,
             )
             t1contextid.append(str(here["ID"]))
-            print(
-                "#" + str(count) + " Context Config ID: " + str(here["ID"]), flush=True
-            )
-        print("Done", flush=True)
+            console.log("#" + str(count) + " Context Config ID: " + str(here["ID"]))
+        console.log("Done")
     return t1contextall, t1contextname, t1contextid
 
 
 def ContextCreate(t1contextall, t1contextname, url_link_final_2, tenant2key):
     t2contextid = []
-    print("Transfering All Context Configuration...", flush=True)
+    console.log("Transfering All Context Configuration...")
     if t1contextname:
         for count, dirlist in enumerate(t1contextname):
             payload = (
@@ -697,19 +686,17 @@ def ContextCreate(t1contextall, t1contextname, url_link_final_2, tenant2key):
                         describe = str(response.text)
                         taskjson1 = json.loads(describe)
                         t2contextid.append(str(taskjson1["ID"]))
-                        print(
+                        console.log(
                             "#"
                             + str(count)
                             + " Context Config name: "
                             + taskjson1["name"],
-                            flush=True,
                         )
-                        print(
+                        console.log(
                             "#"
                             + str(count)
                             + " Context Config ID: "
                             + str(taskjson1["ID"]),
-                            flush=True,
                         )
                 else:
                     payload = t1contextall[count]
@@ -725,18 +712,16 @@ def ContextCreate(t1contextall, t1contextname, url_link_final_2, tenant2key):
                     describe = str(response.text)
                     taskjson = json.loads(describe)
                     t2contextid.append(str(taskjson["ID"]))
-                    print(
+                    console.log(
                         "#" + str(count) + " Context Config name: " + taskjson["name"],
-                        flush=True,
                     )
-                    print(
+                    console.log(
                         "#" + str(count) + " Context Config ID: " + str(taskjson["ID"]),
-                        flush=True,
                     )
             else:
-                print(describe, flush=True)
-                print(payload, flush=True)
-    print("Done!", flush=True)
+                console.log(describe)
+                console.log(payload)
+    console.log("Done!")
     return t2contextid
 
 
@@ -744,7 +729,7 @@ def ScheduleGet(url_link_final, tenant1key):
     t1scheduleall = []
     t1schedulename = []
     t1scheduleid = []
-    print("Getting All Schedule Configuration...", flush=True)
+    console.log("Getting All Schedule Configuration...")
     payload = {}
     url = url_link_final + "api/schedules"
     headers = {
@@ -759,21 +744,18 @@ def ScheduleGet(url_link_final, tenant1key):
         for count, here in enumerate(schedules_json):
             t1scheduleall.append(str(json.dumps(here)))
             t1schedulename.append(str(here["name"]))
-            print(
+            console.log(
                 "#" + str(count) + " Schedule Config name: " + str(here["name"]),
-                flush=True,
             )
             t1scheduleid.append(str(here["ID"]))
-            print(
-                "#" + str(count) + " Schedule Config ID: " + str(here["ID"]), flush=True
-            )
-        print("Done", flush=True)
+            console.log("#" + str(count) + " Schedule Config ID: " + str(here["ID"]))
+        console.log("Done")
     return t1scheduleall, t1schedulename, t1scheduleid
 
 
 def ScheduleCreate(t1scheduleall, t1schedulename, url_link_final_2, tenant2key):
     t2scheduleid = []
-    print("Transfering All Schedule Configuration...", flush=True)
+    console.log("Transfering All Schedule Configuration...")
     if t1schedulename:
         for count, dirlist in enumerate(t1schedulename):
             payload = (
@@ -809,19 +791,17 @@ def ScheduleCreate(t1scheduleall, t1schedulename, url_link_final_2, tenant2key):
                         describe = str(response.text)
                         taskjson1 = json.loads(describe)
                         t2scheduleid.append(str(taskjson1["ID"]))
-                        print(
+                        console.log(
                             "#"
                             + str(count)
                             + " Schedule Config name: "
                             + taskjson1["name"],
-                            flush=True,
                         )
-                        print(
+                        console.log(
                             "#"
                             + str(count)
                             + " Schedule Config ID: "
                             + str(taskjson1["ID"]),
-                            flush=True,
                         )
                 else:
                     payload = t1scheduleall[count]
@@ -837,19 +817,17 @@ def ScheduleCreate(t1scheduleall, t1schedulename, url_link_final_2, tenant2key):
                     describe = str(response.text)
                     taskjson = json.loads(describe)
                     t2scheduleid.append(str(taskjson["ID"]))
-                    print(
+                    console.log(
                         "#" + str(count) + " Schedule Config name: " + taskjson["name"],
-                        flush=True,
                     )
-                    print(
+                    console.log(
                         "#"
                         + str(count)
                         + " Schedule Config ID: "
                         + str(taskjson["ID"]),
-                        flush=True,
                     )
             else:
-                print(describe, flush=True)
-                print(payload, flush=True)
-    print("Done!", flush=True)
+                console.log(describe)
+                console.log(payload)
+    console.log("Done!")
     return t2scheduleid
