@@ -5,6 +5,7 @@ from deepsecurity.rest import ApiException
 import requests
 import urllib3
 import json
+from dsmigrator.logging import console
 from types import SimpleNamespace
 from dsmigrator.api_config import PolicyApiInstance
 from rich.progress import Progress
@@ -13,7 +14,7 @@ cert = False
 
 
 def delete_cloud_one_policies(CLOUD_ONE_API_KEY: str):
-    print("Deleting Policies from Cloud One...")
+    console.log("Deleting Policies from Cloud One...")
 
     host = "https://cloudone.trendmicro.com/api/policies"
     message = requests.get(
@@ -24,11 +25,11 @@ def delete_cloud_one_policies(CLOUD_ONE_API_KEY: str):
     parsed = message.text
     x = json.loads(parsed, object_hook=lambda d: SimpleNamespace(**d))
     policyNumbers = []
-    for key in x.policies:  # ERRORS here
+    for key in x.policies:
         policyNumbers.append(key.ID)
     if policyNumbers:
         for policyID in policyNumbers:
-            print(f"Deleting policy #{policyID}")
+            console.log(f"Deleting policy #{policyID}")
             policyHost = f"https://cloudone.trendmicro.com/api/policies/{policyID}"
             requests.delete(
                 policyHost,
@@ -36,7 +37,7 @@ def delete_cloud_one_policies(CLOUD_ONE_API_KEY: str):
                 headers={"api-secret-key": CLOUD_ONE_API_KEY, "api-version": "v1"},
             )
     else:
-        print("No policies detected in Cloud One. Skipping.")
+        console.log("No policies detected in Cloud One. Skipping.")
 
 
 def ListAllPolicy(url_link_final, tenant1key):
@@ -62,7 +63,7 @@ def GetPolicy(policyIDs, url_link_final, tenant1key):
     antimalwareconfig = []
     allofpolicy = []
     i = 0
-    print("Getting Policy from Deep Security", flush=True)
+    console.log("Getting Policy from Deep Security")
     for count, part in enumerate(policyIDs):
 
         payload = {}
@@ -79,7 +80,7 @@ def GetPolicy(policyIDs, url_link_final, tenant1key):
         describe = str(response.text)
         i = i + 1
         allofpolicy.append(describe)
-        print("#" + str(count) + " Policy ID: " + str(part), flush=True)
+        console.log("#" + str(count) + " Policy ID: " + str(part))
         rtscan = describe.find("realTimeScanConfigurationID")
         if rtscan != -1:
             rtpart = describe[rtscan + 28 :]
@@ -136,7 +137,7 @@ def validate_create(all_old, api_instance, type):
                 id_dict[oldid] = newid
                 if "parentID" in oldjson.keys():
                     api_instance.modify_parent(newid, newparentid)
-                print(
+                console.log(
                     "#"
                     + str(count)
                     + " "
@@ -145,24 +146,23 @@ def validate_create(all_old, api_instance, type):
                     + str(newid)
                     + ", Name: "
                     + newname,
-                    flush=True,
                 )
                 all_new.append(str(newid))
                 namecheck = -1
             except ApiException as e:
                 error_json = json.loads(e.body)
                 if "name already exists" in error_json["message"]:
-                    print(
+                    console.log(
                         f"{oldjson['name']} already exists in new tenant, renaming..."
                     )
                     oldjson["name"] = oldname + " {" + str(rename) + "}"
                     rename = rename + 1
                 else:
-                    print(e.body)
-                    print(
+                    console.log(e.body)
+                    console.log(
                         f"[bold bright_red]WARNING[/bold bright_red]: {oldname} could not be transferred. Please transfer manually."
                     )
-                    print(
+                    console.log(
                         "[i]NOTE: This is under construction and will work soon. :)[/i]"
                     )
                     namecheck = -1
@@ -174,6 +174,6 @@ cert = False
 
 
 def AddPolicy(allofpolicy, NEW_API_KEY):
-    print("Creating Policy to Tenant 2 with new ID", flush=True)
+    console.log("Creating Policy to Tenant 2 with new ID")
     if allofpolicy:
         return validate_create(allofpolicy, PolicyApiInstance(NEW_API_KEY), "policy")
